@@ -1,5 +1,5 @@
 package Git::Database::Object::Commit;
-$Git::Database::Object::Commit::VERSION = '0.007';
+$Git::Database::Object::Commit::VERSION = '0.008';
 use Git::Database::Actor;
 use DateTime;
 use Encode qw( decode );
@@ -12,9 +12,11 @@ with 'Git::Database::Role::Object';
 sub kind {'commit'}
 
 has commit_info => (
-    is        => 'lazy',
+    is        => 'rwp',
     required  => 0,
     predicate => 1,
+    lazy      => 1,
+    builder   => 1,
 );
 
 sub BUILD {
@@ -41,14 +43,23 @@ for my $attr (
 
 sub parents_digest { @{ $_[0]->commit_info->{parents_digest} ||= [] }; }
 
-# assumes commit_info is set
 sub _build_content {
     my ($self) = @_;
 
-    return Git::Database::Role::Object::_build_content($self)
-      if !$self->has_commit_info;
+    if ( !$self->has_commit_info ) {
+        my $attr = $self->_get_object_attributes();
+        return $attr->{content} if exists $attr->{content};
 
-    my $content .= 'tree ' . $self->tree_digest . "\n";
+        if ( exists $attr->{commit_info} ) {
+            $self->_set_commit_info( $attr->{commit_info} );
+        }
+        else {
+            die "Can't build content from these attributes: "
+              . join( ', ', sort keys %$attr );
+        }
+    }
+
+    my $content  = 'tree ' . $self->tree_digest . "\n";
     $content .= "parent $_\n" for $self->parents_digest;
     $content .= join(
         ' ',
@@ -70,9 +81,22 @@ sub _build_content {
     return $content;
 }
 
-# assumes content is set
 sub _build_commit_info {
-    my $self = shift;
+    my ($self) = @_;
+
+    if ( !$self->has_content ) {
+        my $attr = $self->_get_object_attributes();
+        return $attr->{commit_info} if exists $attr->{commit_info};
+
+        if ( exists $attr->{content} ) {
+            $self->_set_content( $attr->{content} );
+        }
+        else {
+            die "Can't build content from these attributes: "
+              . join( ', ', sort keys %$attr );
+        }
+    }
+
     my @lines = split "\n", $self->content;
 
     # parse the headers
@@ -148,7 +172,7 @@ Git::Database::Object::Commit - A commit object in the Git object database
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -240,8 +264,9 @@ One (and only one) of the C<content> or C<commit_info> arguments is
 required.
 
 C<commit_info> is a reference to a hash containing the keys listed
-above, i.e. C<tree_digest>, C<author>, C<author_date>, C<committer>,
-C<committed_date>, C<comment>, and C<encoding> (optional).
+above, i.e. C<tree_digest>, C<parents_digest> (optional), C<author>,
+C<author_date>, C<committer>, C<committer_date>, C<comment>, and
+C<encoding> (optional).
 
 =head1 SEE ALSO
 
