@@ -1,5 +1,5 @@
 package Git::Database::Role::ObjectReader;
-$Git::Database::Role::ObjectReader::VERSION = '0.007';
+$Git::Database::Role::ObjectReader::VERSION = '0.008';
 use Git::Database::Object::Blob;
 use Git::Database::Object::Tree;
 use Git::Database::Object::Commit;
@@ -47,7 +47,7 @@ Git::Database::Role::ObjectReader - Abstract role for a Git backends that read o
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -102,7 +102,8 @@ returns the full object extracted from the Git database (one of
 L<Git::Database::Object::Blob>, L<Git::Database::Object::Tree>,
 L<Git::Database::Object::Commit>, or L<Git::Database::Object::Tag>).
 
-Returns C<undef> if the object is not in the Git database.
+Returns C<undef> if the object is not in the Git database or if the
+abbreviated digest is ambiguous.
 
 =head2 get_object_meta
 
@@ -142,7 +143,39 @@ all the attributes needed to create a new object (if the requested object
 is in the database). This method is typically used by L</get_object>
 to create the actual object instance.
 
-Otherwise return the C<undef> value.
+Return C<undef> if the object is not in the Git database or if the
+abbreviated digest is ambiguous.
+
+The exact content of the hash reference returned by C<get_object_attributes>
+may vary, but there are certain minimum requirements:
+
+=over 4
+
+=item *
+
+The C<kind> key is B<required>.
+
+=item *
+
+The C<size> key is B<required>, if the backend does not provide its own
+L</get_object_meta> implementation (as the default implementation depends
+on L</get_object_attributes> to obtain the metadata).
+
+=item *
+
+If present, the C<digest> value B<must> be the full digest (40 hexadecimal
+digits).
+
+=item *
+
+Although most backends return the C<content> attribute, it is not strictly
+required (except for a blob). For a tree, a backend can instead return
+the L<directory_entries|Git::Database::Object::Tree/directory_entries>
+attribute (a list of L<Git::Database::DirectoryEntry> objects). Likewise,
+it can also provide L<commit_info|Git::Database::Object::Commit/commit_info>
+for a commit and L<tag_info|Git::Database::Object::Tag/tag_info> for a tag.
+
+=back
 
 =head2 all_digests
 
